@@ -9,8 +9,6 @@ require(testthat)
 context("ISOBaseBoolean")
 
 test_that("encoding",{
-  testthat::skip_on_cran()
-  testthat::skip_on_travis()
   #encoding
   md <- ISOBaseBoolean$new(value = TRUE)
   expect_is(md, "ISOBaseBoolean")
