@@ -19,7 +19,7 @@ test_that("encoding",{
   
   cit = ISOCitation$new()
   cit$setTitle("title")
-  cit$setAlternateTitle("alternate title")
+  cit$addAlternateTitle("alternate title")
   d <- ISODate$new()
   d$setDate(ISOdate(2015,1,1))
   d$setDateType("creation")
@@ -31,8 +31,8 @@ test_that("encoding",{
   rp = ISOResponsibleParty$new()
   rp$setRole("publisher")
   rp$setContactInfo(contact)
-  cit$setCitedResponsibleParty(rp)
-  md$addFeatureCatalogueCitation(cit)
+  cit$addCitedResponsibleParty(rp)
+  md$addFeatureCatalogueCitation(cit, "someuuid")
   expect_is(md, "ISOFeatureCatalogueDescription")
   xml <- md$encode()
   expect_is(xml, "XMLInternalNode")
