@@ -9,7 +9,8 @@ require(testthat)
 context("ISOReferenceSystem")
 
 test_that("encoding/decoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOReferenceSystem$new()
   rsId <- ISOReferenceIdentifier$new(code = "4326", codeSpace = "EPSG")
