@@ -9,7 +9,8 @@ require(testthat)
 context("ISORepresentativeFraction")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISORepresentativeFraction$new(denominator = 1L)
   xml <- md$encode()
